import { APIGatewayProxyEvent, Context } from 'aws-lambda';
import { LambdaRouter, RouterParams, Context as RouterContext } from 'lambda-router';
import { RouterInterface, Event, ResourceInterface } from './RouterInterface';
export declare abstract class AbstractRouter implements RouterInterface {
    constructor(routerParams?: RouterParams);
    protected readonly router: LambdaRouter;
    protected readonly logger: any;
    protected readonly tracingEnabled: boolean;
    addResources: (resources: LambdaRouterResourceInterface[]) => void;
    route: (event: APIGatewayProxyEvent, context: Context) => Promise<{
        isOk: boolean;
        endpoint: string;
        uri: string;
        response: {
            statusCode: number;
            body: string;
            headers: Record<string, string>;
        };
    }>;
    protected obfuscateSecrets(event: Event, _context: RouterContext, _path: string, _method: string): void;
    protected logRequest: (event: Event, _context: RouterContext, _path: string, _method: string) => void;
    /** Response on resource / method not found */
    protected abstract onUnknown(event: Event, context: RouterContext, path: string, method: string): any;
    /** Mutates the event/context and perform global scope validations */
    protected abstract beforeRoute(event: Event, context: RouterContext, path: string, method: string): void;
}
interface LambdaRouterResourceInterface extends ResourceInterface {
    path: string;
    get?: (event: Event, context: RouterContext) => Promise<any>;
    post?: (event: Event, context: RouterContext) => Promise<any>;
    put?: (event: Event, context: RouterContext) => Promise<any>;
    delete?: (event: Event, context: RouterContext) => Promise<any>;
}
export {};
